<?php
/**
* @package paristemi
* @subpackage paristemi_util
* <b>Calendar Class</b><br />
* A collection of functions for working with the calendar.
* A section of the functions deal with date manipulation.
* The other section of functions work on the display of calendars.
* This section is searchable.
* @author Kristen O'Brien <kristen_paristemi-com>
* @copyright Copyright 2004, Kristen O'Brien
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
* @link http://www.paristemi.com Paristemi Main Site
* @since Build 0.5
* @version Build 0.8
* @filesource
*/
/**
* Include the constants file and all of the files in the include list
*/
if(isset($SERVER_DIRECTORY) && file_exists($SERVER_DIRECTORY."constants.php")) { require_once($SERVER_DIRECTORY."constants.php"); } else if(ltrim(dirname($_SERVER['SCRIPT_FILENAME'])) != "" && file_exists($_SERVER['DOCUMENT_ROOT']."/constants.php")) {     require_once($_SERVER['DOCUMENT_ROOT']."/constants.php"); } else if(file_exists("../constants.php")) { require_once("../constants.php"); } else { require_once("constants.php"); }
foreach($INCLUDE_LIST as $includefile) { require_once $includefile; }

/**
* @package paristemi
* @subpackage paristemi_util
* <b>Calendar Class</b><br />
* A collection of functions for working with the calendar.
* A section of the functions deal with date manipulation.
* The other section of functions work on the display of calendars.
* This section is searchable.
* @author Kristen O'Brien <kristen_paristemi-com>
* @copyright Copyright 2004, Kristen O'Brien
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
* @link http://www.paristemi.com Paristemi Main Site
* @since Build 0.5
* @version Build 0.8
* @filesource
*/
class Calendar {
      
     function Calendar() { }
      
     function DateDayGreater($date1,$date2) {
    	return (($date1['year'] >= $date2['year'])
    			&& ($date1['mon'] >= $date1['mon'])
    			&& ($date1['mday'] > $date2['mday']));
      }
      
     function &getWeekdayNumber($weekday)
	 {
		switch($weekday) {
			case $GLOBALS['S_WEEK_FULL_SUN'] : return 0;
			case $GLOBALS['S_WEEK_FULL_MON'] : return 1;
			case $GLOBALS['S_WEEK_FULL_TUE'] : return 2;
			case $GLOBALS['S_WEEK_FULL_WED'] : return 3;
			case $GLOBALS['S_WEEK_FULL_THU'] : return 4;
			case $GLOBALS['S_WEEK_FULL_FRI'] : return 5;
			case $GLOBALS['S_WEEK_FULL_SAT'] : return 6;
			default : return null;
		}
	}
 
     function &getWeekday ($dayvalue) {
        switch ($dayvalue) {
            case 0 : return $GLOBALS['S_WEEK_FULL_SUN'];
            case 1 : return $GLOBALS['S_WEEK_FULL_MON'];
            case 2 : return $GLOBALS['S_WEEK_FULL_TUE'];
            case 3 : return $GLOBALS['S_WEEK_FULL_WED'];
            case 4 : return $GLOBALS['S_WEEK_FULL_THU'];
            case 5 : return $GLOBALS['S_WEEK_FULL_FRI'];
            case 6 : return $GLOBALS['S_WEEK_FULL_SAT'];
        }
     }
 
     function &getNextMonth($m,$y)
     {
        $nextmonth = $m+1;
        $nextyear = $y;
                     
        if($nextmonth > 12) {
            $nextmonth = 1;
            $nextyear++;
        }
        return array($nextmonth,$nextyear);
     }
    
     function &getLastMonth($m,$y)
     {
        $lastmonth = $m-1;
        $lastyear = $y;
        
        if($lastmonth < 1) {
            $lastmonth = 12;
            $lastyear--;
        }
        return array($lastmonth,$lastyear);
     }
   
      function &incDay ($today)
      {
			$total_days = getdate(mktime(0,0,0,$today['mon']+1,1,$today['year'])-1);
         if($today['mday']++ > $total_days) {
            if($today['mon']++ > 12) {
               $next_day = getdate(mktime(0,0,0,1,1,$today['year']++));
            }
            else {
               $next_day = getdate(mktime(0,0,0,$today['mon']++,1,$today['year']));
            }
         }
         else {
            $next_day = getdate(mktime(0,0,0,$today['mon'],$today['mday']++,$today['year']));
         }
         return $next_day;
      }
      
      function &decDay ($today)
      {
			$total_days = getdate(mktime(0,0,0,$today['mon']+1,1,$today['year'])-1);
         if($today['mday']-- < 1) {
            if($today['mon']-- < 1) {
               $prev_day = getdate(mktime(0,0,0,12,31,$today['year']--));
            }
            else {
               $total_days = getdate(mktime(0,0,0,$today['mon'],1,$today['year'])-1);
               $prev_day = getdate(mktime(0,0,0,$today['mon']--,$total_days,$today['year']));
            }
         }
         else {
            $prev_day = getdate(mktime(0,0,0,$today['mon'],$today['mday']--,$today['year']));
         }
         return $prev_day;
      }
      
		function &nextDay ($day_marker,$begin_week)
		{
			$total_days = getdate(mktime(0,0,0,$begin_week['mon']+1,1,$begin_week['year'])-1);
			if($total_days['mday'] < ($begin_week['mday']+$day_marker)) {
				if($begin_week['mon']+1 > 12) {
					$next_day = getdate(mktime(0,0,0,1,($begin_week['mday']+$day_marker) - $total_days['mday'], $begin_week['year']+1));
				}
				else {
               $next_day = getdate(mktime(0, 0, 0, ($begin_week['mon']+1), (($begin_week['mday']+$day_marker) - $total_days['mday']), $begin_week['year']));
				}
			}
			else {
				$next_day = getdate(mktime(0,0,0,$begin_week['mon'],($begin_week['mday']+($day_marker)),$begin_week['year']));
			}
			return $next_day;
		}
      
      function &previousDay ($day_marker,$begin_week)
		{
			$total_days = getdate(mktime(0,0,0,$begin_week['mon']+1,1,$begin_week['year'])-1);
			if(($begin_week['mday']+$day_marker) < 1) {
				if($begin_week['mon']-1 < 1) {
					$prev_day = getdate(mktime(0,0,0,12,($begin_week['mday']-day_marker) + $total_days['mday'], $begin_week['year']-1));
				}
				else {
               $prev_day = getdate(mktime(0, 0, 0, ($begin_week['mon']-1), (($begin_week['mday']-$day_marker) + $total_days['mday']), $begin_week['year']));
				}
			}
			else {
				$prev_day = getdate(mktime(0,0,0,$begin_week['mon'],($begin_week['mday']-($day_marker)),$begin_week['year']));
			}
			return $prev_day;
		}
		
		function &beginWeek ($today)
		{
			$diff_begin = ($today['mday'] - $today['wday']);
			if($diff_begin < 1) {
				if($today['mon'] == 1) {
					$end_day = getdate(mktime(0,0,0,1,1,$today['year'])-1);
					$begin_week = getdate(mktime(0,0,0,12,$end_day['mday']+$diff_begin,$today['year']-1));
				}
				else {
					$end_day = getdate(mktime(0,0,0,$today['mon'],1,$today['year'])-1);
					$begin_week = getdate(mktime(0,0,0,$today['mon']-1,$end_day['mday']+$diff_begin,$today['year']));
				}
			}
			else {
				$begin_week = getdate(mktime(0, 0, 0, $today['mon'], $diff_begin, $today['year']));
			}
			return $begin_week;
		}
		
		function &endWeek ($today)
		{
			$total_days = getdate(mktime(0,0,0,$today['mon']+1,1,$today['year'])-1);
			$diff_end = ($today['mday'] + (6 - $today['wday']));
			if($total_days['mday'] < $diff_end) {
				if($today['mon']+1 > 12) {
               
					$end_week = getdate(mktime(0,0,0,1,$diff_end - $total_days['mday'], $today['year']+1));
				}
				else {
					$end_week = getdate(mktime(0, 0, 0, $today['mon']+1, $diff_end - $total_days['mday'], $today['year']));					}
				}
			else {
				$end_week = getdate(mktime(0,0,0,$today['mon'],$diff_end,$today['year']));
			}
			return $end_week;
		}
		
	  function &nextEventFromRecursive(&$value)
	  {
	    $recstamp = 0;
	    $today = time();
	    $meetdays = 0;
        if(!empty($value->SeriesArr) && isset($value->SeriesArr[0]) && $value->SeriesArr[0]->ID != 0) {
            $meetdays = $value->SeriesArr[0]->MeetByMonth;
        }
        if($value->Recursive && $value->RecEnd[0] >= $today) {
           	$todaydate = getdate($today);
           	$day= $todaydate['mday']; 
           	$mkr = $day; $addflg=false;$useday = 0;
            if($meetdays==0) { $addflg = true; }
            else {
            	$laststamp=mktime(23,59,59,$todaydate['mon'],$todaydate['mday'],$todaydate['year']);
        		$last = getdate($laststamp);
        		$nextmonth = $last['mon']+1;
        		$nextyear = $last['year'];
        		if($nextmonth > 12) { $nextmonth = 1; $nextyear++; }
        		$endstamp = (mktime(0,0,0,$nextmonth,1,$nextyear)-1);
        		$endmonth = getdate($endstamp);
        		$endrec = getdate($value->RecEnd[0]);
                $meetdays = explode(',',$meetdays);
                while($mkr > 0) { $mkr = $mkr-7; }
                $continue=true;
                while($continue && !isset($usemon)) {
                	if($endrec['mon']==$endmonth['mon'] && $endrec['year']==$endmonth['year']) {
                		$endmday = $endrec['mday']; }
                	else { $endmday = $endmonth['mday']; }
                	$mkr = $endmday; $dayarr=array();
                	while($mkr > 0) { $mkr = $mkr-7; }
               	$i=$mkr; while($i<=$endmday) { $dayarr[]=$i;$i=$i+7; }
                	foreach($meetdays as $meetingdays) {
                 	if($dayarr[$meetingdays] >= $day) { 
                        $dayarrdate = getdate(mktime(0,0,0,$endmonth['mon'],$dayarr[$meetingdays],$endmonth['year']));
                         $daydiff = $this->getWeekDayNumber($value->RecDay) - $dayarrdate['wday'];
                 		$addflg=true; $useday=$dayarrdate['mday']+$daydiff; 
                 		$usemon=$endmonth['mon']; $useyear=$endmonth['year'];
                         $continue = false; break;
                 	}
                 }
                 $nextmonth = $nextmonth+1;
        			$nextyear = $nextyear;
        			if($nextmonth > 12) { $nextmonth = 1; $nextyear++; }
        			$endstamp = (mktime(0,0,0,$nextmonth,1,$nextyear)-1);
        			$endmonth = getdate($endstamp);
        			if($value->RecEnd[0] >= $endstamp){$continue=true;}
                	elseif($endrec['mon'] >= $endmonth['mon']){
                		if($endrec['year']==$endmonth['year']) {$continue=true;}
                		else {$continue=false;}}
                	elseif($endrec['year'] > $endmonth['year']){$continue=true;}
                	else{$continue=false;}
                	$day =1;
                }
            }
            if($addflg) { 
           	 $start = getdate($value->Start);
           	 $recday = $this->getWeekdayNumber($value->RecDay);
           	 $recdate = $this->nextDay($recday,$this->beginWeek($todaydate));
           	 $recstamp = mktime($start['hours'],$start['minutes'],$start['seconds'],
           	 					$recdate['mon'],$recdate['mday'],$recdate['year']);
           	 if($useday==0) {
           	 	if($recstamp < $today) {
           	 		$todaydate = getdate($today+604800);
           	 		$recdate = $this->nextDay($recday,$this->beginWeek($todaydate));
           	 		$recstamp = mktime($start['hours'],$start['minutes'],$start['seconds'],
           	 					$recdate['mon'],$recdate['mday'],$recdate['year']);
           	 	} 
           	 }
           	 else { 
           	 	$recstamp = mktime($start['hours'],$start['minutes'],$start['seconds'],
           	 						$usemon,$useday,$useyear);
           	 }
            }
        }
        return ($recstamp > $value->RecEnd[0]) ? 0 : $recstamp;
	  }
        
      function &getImageSmall ($type)
      { return $GLOBALS['CAL_ICON_LIST'][$type]['small']; }
      
      function &getImageLarge ($type)
      { return $GLOBALS['CAL_ICON_LIST'][$type]['large']; }
      
      function &incImage ($image,&$bs_count,&$lg_count,&$sg_count,&$mm_count,&$se_count)
      {
          $prefix = substr($image, 0,1);
          switch ($prefix) {
              case "bs" : $bs_count++; if($bs_count > 1){ return true; }; break;
              case "lg" : $lg_count++; if($lg_count > 1){ return true; };break;
              case "sg" : $sg_count++; if($sg_count > 1){ return true; };break;
              case "mm" : $mm_count++; if($mm_count > 1){ return true; };break;
              case "se" : $se_count++; if($se_count > 1){ return true; };break;
              case "bc" : $bc_count++; if($bc_count > 1){ return true; };break;
              default : return false; break;
          }
          return false;
      }
      
      function calIcons($printicons=1) {
         $tblclass = "calicons";
         $tblarr = array();
         foreach($GLOBALS['CAL_ICON_LIST'] as $icon_name=>$icon_values) {
            $tbldata = array("<img align=\"middle\" src=\"".
                            $GLOBALS['HTTP_DOCUMENT_ROOT'].$GLOBALS['IMAGE_PATH'].
                            $icon_values['small']."\" alt=\"".
                            $GLOBALS['S_CAL_ICON_LIST'][$icon_name]."\" />",
                            $GLOBALS['S_CAL_ICON_LIST'][$icon_name]);
            array_push($tblarr,$tbldata);
         }
         $icontable = UtilHtml::createTable($tblarr,"",$tblclass,"<br /><br />");
         if($printicons) { echo $icontable; }
         else { return $icontable; }
      }
      
      function calLinks($space,$printout=1) {
        $returntext = "";
      	if($space) {
         $returntext .= "<h2>".$GLOBALS['S_CALENDAR']."</h2>";
         $returntext .= "<p class=\"leftlinks\">";
      	}
        $returntext .= "<a href=\"".$GLOBALS['HTTP_DOCUMENT_ROOT'].$GLOBALS['CALENDAR_PATH'].
              $GLOBALS['MONTH_CAL_FILE']."\">".$GLOBALS['S_MONTH']."</a>";
        if($space) { $returntext .= "</p><p class=\"leftlinks\">"; }
        else { $returntext .= "&nbsp;&nbsp;|&nbsp;&nbsp;"; }
        $returntext .= "<a href=\"".$GLOBALS['HTTP_DOCUMENT_ROOT'].$GLOBALS['CALENDAR_PATH'].
              $GLOBALS['WEEK_CAL_FILE']."\">".$GLOBALS['S_WEEK']."</a>";
        if($space) { $returntext .= "</p><p class=\"leftlinks\">"; }
        else { $returntext .= "&nbsp;&nbsp;|&nbsp;&nbsp;"; }
        $returntext .= "<a href=\"".$GLOBALS['HTTP_DOCUMENT_ROOT'].$GLOBALS['CALENDAR_PATH'].
              $GLOBALS['DAY_CAL_FILE']."\">".$GLOBALS['S_TODAY']."</a>";
        if($space) { $returntext .= "</p>"; }
        if($printout) { echo $returntext; }
        else { return $returntext; }
      }
      
    function calLinksSmarty() {
       $sidesection = array();
       $sidesection['Title'] = $GLOBALS['S_CALENDAR'];
       $sidesection['Links'] = array();
       $sidesection['Links'][] = array(
          'LinkPath' => $GLOBALS['HTTP_DOCUMENT_ROOT'].$GLOBALS['CALENDAR_PATH'].$GLOBALS['MONTH_CAL_FILE'],
          'LinkText' => $GLOBALS['S_MONTH']);
       $sidesection['Links'][] = array(
          'LinkPath' => $GLOBALS['HTTP_DOCUMENT_ROOT'].$GLOBALS['CALENDAR_PATH'].$GLOBALS['WEEK_CAL_FILE'],
          'LinkText' => $GLOBALS['S_WEEK']);
       $sidesection['Links'][] = array(
          'LinkPath' => $GLOBALS['HTTP_DOCUMENT_ROOT'].$GLOBALS['CALENDAR_PATH'].$GLOBALS['DAY_CAL_FILE'],
          'LinkText' => $GLOBALS['S_TODAY']);
       return $sidesection;
    }
    
    function &calSearchForm(&$smarty)
    {
	    $smarty->assign('searchformname','calsearch');
	    $smarty->assign('searchformfile',$GLOBALS['HTTP_DOCUMENT_ROOT'].$GLOBALS['CALENDAR_PATH'].$GLOBALS['WEEK_CAL_FILE']);
	    $smarty->assign('searchconstraints',array(
	        array('name'=>'Title','title'=>$GLOBALS['S_TITLE']),
            array('name'=>'STitle','title'=>$GLOBALS['S_STUDIES']),
	        array('name'=>'Description','title'=>$GLOBALS['S_DESC'])));
	    $smarty->assign('searchsubmittitle',$GLOBALS['S_EVENT']." ".$GLOBALS['S_SEARCH']);
        return $smarty;
    }
      
      function calHeader() {
         return array('callinks'=>$this->calLinksSmarty(),'calicons'=>$this->calIcons(0));
      }
      
      function &currentEvents($data,$showfirstlinks=1,$showlastlinks=1,
      			$title="",$no_events="")
      {
        $smarty = UtilSmarty::createSmarty();
        $smarty->assign('adminbar_section_name',$S_CALENDAR);
        $smarty->assign('adminbar_section_add','calendar');
         if($title == "") { $title=$GLOBALS['S_UPCOMING_EVENTS']; }
         if($no_events == "") { $no_events=$GLOBALS['S_UPCOMING_EVENTS_NONE']; }
         $returntext = "<h2>".$title."</h2>";
         if($showfirstlinks) { $returntext .= "<br />".$this->calLinks(0,0); }
         if($data != null) {
            $tblheader = array($GLOBALS['S_DATE'],$GLOBALS['S_DAY'],$GLOBALS['S_START'],$GLOBALS['S_EVENT']);
            $tblclass = "tbl-currevents";
            $tbltrclass = "";
            $tbltdclass = array("td-currevents-date","td-currevents-day",
                                "td-currevents-start","td-currevents-event");
            $tblarr = array();
            foreach ($data as $value) {
               $smarty->assign('adminitem_id',$value->ID);
               $smarty->assign('adminitem_title',$value->Title);
               $this_day = $value->Start;
               if($value->Start['hours'] == $value->Stop['hours'] && 
                  $value->Start['minutes'] == $value->Stop['minutes'] && !$value->Recursive) {
                      $displaytime = "&nbsp;";
                  }
               else { $displaytime = date("g:i A",$this_day[0]); }
               $image =& $this->getImageSmall($value->Type);
               $imagetxt = "<img src=\"".$GLOBALS['HTTP_DOCUMENT_ROOT'].$GLOBALS['IMAGE_PATH'].
                            $image."\" border=\"0\" alt=\"".$GLOBALS['S_CAL_ICON_LIST'][$value->Type]."\" />";
               $linktxt .= "<a href=\"".$GLOBALS['HTTP_DOCUMENT_ROOT'].
                          $GLOBALS['CALENDAR_PATH'].$GLOBALS['ITEM_CAL_FILE'].
                          "?id=".$value->ID."\">";
             if(empty($value->SeriesArr) || $value->SeriesArr[0]->ID == 10) {
                 $seriestitle = "";
                 if($value->Type == $GLOBALS['S_HOME_GROUP']) { $seriestitle = ""; }
                 else if($value->Type == $GLOBALS['S_BIBLE_COLLEGE']) { $seriestitle = " - ".$GLOBALS['S_BIBLE_COLLEGE']; }
                 $tbldata = array($this_day['month']." ".$value->Start['mday'],
                              $this_day['weekday'],$displaytime,
                              $smarty->fetch('adminitembar.tpl').
                              $linktxt.$imagetxt."</a>&nbsp;".$linktxt.
                              $value->Title.$seriestitle."</a>");
                 array_push($tblarr,$tbldata);
             }
             else {
                foreach($value->SeriesArr as $series) {
                   $seriestitle = "";
                   if($value->Type == $GLOBALS['S_HOME_GROUP'] || $series->Title == 'No Series') { $seriestitle = ""; }
                   else if($value->Type == $GLOBALS['S_BIBLE_COLLEGE']) { $seriestitle = " - ".$GLOBALS['S_BIBLE_COLLEGE']; }
                   else if($value->Title != $series->Title) { $seriestitle = " - ".$series->Title; }
                   $tbldata = array($this_day['month']." ".$value->Start['mday'],
                                $this_day['weekday'],$series->Start,
                                $smarty->fetch('adminitembar.tpl').
                                $linktxt.$imagetxt."</a>&nbsp;".$linktxt.
                                $value->Title.$seriestitle."</a>");
                   array_push($tblarr,$tbldata);
                }
             }
            }
            $returntext .= UtilHtml::createTable($tblarr,$tblheader,$tblclass,"",$tbltrclass,$tbltdclass);
          }
          else { $returntext .= $no_events."<br />"; }
          if($showlastlinks) { $returntext .= "<br />".$this->calLinks(0,0); }
          return $returntext;
      }
      
      function &printcal($y, $m, $monfile, $linklocation, $linklocationday, $printvals) {  
         $db = new Database();
         $db_cal = $db->GetClass('cal');
         if($printvals) { $tblclass = "moncal"; }
         else { $tblclass = "moncalblank"; }

         $month_name = getdate(mktime(0, 0, 0, $m, 1, $y));
         $next = $this->getNextMonth($m,$y);
         $prev = $this->getLastMonth($m,$y);
         $tblarr = array();
         $tblheader = array(
                        "<a href=\"".$monfile."?mon=".$prev[0]."&amp;year=".$prev[1]."\">&lt;&lt;</a>".
                        "&nbsp; &nbsp;".$month_name['month']." ".$y."&nbsp; &nbsp;".
                        "<a href=\"".$monfile."?mon=".$next[0]."&amp;year=".$next[1]."\">&gt;&gt;</a>",
                        array($GLOBALS['S_WEEK_SUN'],$GLOBALS['S_WEEK_MON'],$GLOBALS['S_WEEK_TUE'],
                            $GLOBALS['S_WEEK_WED'],$GLOBALS['S_WEEK_THU'],$GLOBALS['S_WEEK_FRI'],$GLOBALS['S_WEEK_SAT']));
        
        $today=getdate(time());
        $begin_month_assoc=getdate(mktime(0, 0, 0, $m, 1, $y));
        $begin_month_wday=$begin_month_assoc["wday"];
        $curr_month_name=$begin_month_assoc["month"]." ".$begin_month_assoc["year"];
        $end_month_assoc=getdate(mktime(0,0,0,$m+1,1,$y) - 1); 
        $end_month_day=$end_month_assoc["mday"];

        if($printvals) { $data =& $db_cal->GetMonthData($begin_month_assoc); }
        $tblrowdata = array();
        for ($x=0; $x < $begin_month_wday; $x++) { array_push($tblrowdata,"&nbsp;"); }
        for ($day=1; $day <= $end_month_day; $day++) {
           $x++;
           $daytext = "<div class=\"right\">".
                "<a href=\"".$linklocationday."?mon=".$m."&amp;day=".$day."&amp;year=".$y."\">";
           if($day==$today['mday'] && $m==$today['mon']) { $daytext .= "<b>"; }
           $daytext .= $day;
           if($day==$today['mday'] && $m==$today['mon']) { $daytext .= "</b>"; }
           $daytext .= "</a><br /></div>";
           $bs_count=0; $lg_count=0; $sg_count=0; $mm_count=0; $se_count=0;
           if($printvals) {
                 foreach ($data as $value) {
                   if($value->Day == $day) {
                      $image =& $this->getImageSmall($value->Type);
                      if(!($this->incImage($image,$bs_count,$lg_count,$sg_count,$mm_count,$se_count))) {
                         $daytext .= "<a href=\"".$linklocation."?id=".$value->ID."\"><img src=\"";
                         $daytext .= $GLOBALS['HTTP_DOCUMENT_ROOT'].$GLOBALS['IMAGE_PATH'];
                         $daytext .= $image."\" border=\"0\" alt=\"".$value->Title."\" /></a>&nbsp;\n";
                      }
                    }
                   }
          }
          array_push($tblrowdata,$daytext);
          if ($x==7) { array_push($tblarr,$tblrowdata); $tblrowdata=array(); $x=0; }
        }
        for (;$x<7 and $x > 0;$x++) { array_push($tblrowdata,"&nbsp;"); }
        array_push($tblarr,$tblrowdata);
        if($printvals) {
            $tblfooter = "<a href=\"".$monfile."?mon=".$prev[0]."&amp;year=".$prev[1];
            $tblfooter .= "\">&lt;&lt; ".$GLOBALS['S_PREV_MONTH']."</a>";
            $tblfooter .= "&nbsp;&nbsp;|&nbsp;&nbsp;<a href=\"".$monfile."?mon=".$next[0];
            $tblfooter .= "&amp;year=".$next[1]."\">".$GLOBALS['S_NEXT_MONTH']." &gt;&gt;</a>";
        }
        else { $tblfooter = ""; }
        return UtilHtml::createTable($tblarr,$tblheader,$tblclass,$tblfooter);
      }
      
      function &eventTable($item)
      {
          $smarty = UtilSmarty::createSmarty();
          $smarty->assign('adminbar_section_name',$S_CALENDAR);
          $smarty->assign('adminbar_section_add','calendar');
          $smarty->assign('adminitem_id',$item->ID);
          $smarty->assign('adminitem_title',$item->Title);
          $tblheader = $smarty->fetch('adminitembar.tpl');
          
          $tblclass = "tbl-listing";
          $tbltdclass = array("tbl-listing-title","tbl-listing-item");
          $image =& $this->getImageLarge($item->Type);
          $tblheader .= "<img align=\"middle\" src=\"".$GLOBALS['HTTP_DOCUMENT_ROOT'].$GLOBALS['IMAGE_PATH'].
             $image."\" border=\"0\"  alt=\"".$GLOBALS['S_CAL_ICON_LIST'][$item->Type]."\"/>".
             "<span class=\"sectioncurrent\">&nbsp;".$item->Title;
	      if(!empty($item->SeriesArr) && $item->SeriesArr[0]->ShowItem) { 
             if($item->Type == $GLOBALS['S_HOME_GROUP']) { /*Do Nothing*/ }
	         else if($item->Title != $item->SeriesArr[0]->Title) { $tblheader .= " - ".$item->SeriesArr[0]->Title; }
             if($item->Type == $GLOBALS['S_BIBLE_COLLEGE']) { $tblheader .= " - ".$GLOBALS['S_BIBLE_COLLEGE']; }
	      }
	      $tblheader .= "</span>";
	     
	      $tblarr = array();
	      $printdate = "";
	       if($item->Recursive) {
	          $printdate .= $GLOBALS['S_EVERY']." ";
              $meetbymonth = 0;
              if(!empty($item->SeriesArr) && isset($item->SeriesArr[0])) {
                  $meetbymonth = $item->SeriesArr[0]->MeetByMonth;
              }
	          if($meetbymonth != 0) {
	             $printdate .= str_replace(",",", ",str_replace("1",$GLOBALS['S_FIRST'],str_replace("2",$GLOBALS['S_SECOND'],
	                 str_replace("3",$GLOBALS['S_THIRD'],str_replace("4",$GLOBALS['S_FOURTH'],$meetbymonth)))));
	          }
	          $printdate .= " ".$item->RecDay." ".$GLOBALS['S_FROM']." ";
	       }
	       if($item->Start['year'] == $item->Stop['year'] &&
	             $item->Start['mon'] == $item->Stop['mon'] &&
	             $item->Start['mday'] == $item->Stop['mday']) { 
	                $printdate .= $item->Start['month']." ".$item->Start['mday'].
	                      ", ".$item->Start['year'];
	             }
	        else {
	                $printdate .= $item->Start['month']." ".$item->Start['mday'].
	                      ", ".$item->Start['year']." - ";
	                $printdate .= $item->Stop['month']." ".$item->Stop['mday'].
	                      ", ".$item->Stop['year'];
	          }
	        if($item->Recursive) {
	           $printdate .= " ".$GLOBALS['S_TO']." ".$item->RecEnd['month']." ".$item->RecEnd['mday'].", ".$item->RecEnd['year'];
	        }
	        array_push($tblarr,array($GLOBALS['S_DATE'],$printdate));
	        if($item->Recursive) {
	         $recstamp = $this->nextEventFromRecursive($item);
	         if($recstamp != 0) {
	             $recdate = getdate($recstamp);
	             array_push($tblarr,array($GLOBALS['S_NEXT_EVENT'],
	              $recdate['month']." ".$recdate['mday'].", ".$recdate['year']));
	         }
	        }
            $hasmoreseries = false;
            if(!empty($item->SeriesArr) && isset($item->SeriesArr[1])) { $hasmoreseries = true; }
	          $printtime = "";
	          if($hasmoreseries) { $printtimehead = $GLOBALS['S_TIMES']; }
	          else { $printtimehead = $GLOBALS['S_TIME']; }
	          if($hasmoreseries) { $printtime .= "<font size=\"1\">&#8226;</font> "; }
	          $stime = mktime($item->Start['hours'],$item->Start['minutes'],00,01,01,1970);
	          $printtime .= date("g:i A",$stime)." - ";
	          $sptime = mktime($item->Stop['hours'],$item->Stop['minutes'],00,01,01,1970);
	          $printtime .= date("g:i A",$sptime);
	          for($seriesindex=1; $seriesindex < count($item->SeriesArr); $seriesindex++) {
	             $printtime .= "<br /><font size=\"1\">&#8226;</font> ".$item->SeriesArr[$seriesindex]->Start.
                                 " - ".$item->SeriesArr[$seriesindex]->Stop;
	          }
              if(($item->Start['hours'] != $item->Stop['hours']) 
                  || ($item->Start['minutes'] != $item->Stop['minutes'])) {
	                 array_push($tblarr,array($printtimehead,$printtime));
              }
	       if($item->LName != $GLOBALS['S_FORM_LOC']
	          && $item->LName != $GLOBALS['N_LOC_NONE']) { 
	          array_push($tblarr,array($GLOBALS['S_LOCATION'],"<a href=\"".$GLOBALS['HTTP_DOCUMENT_ROOT'].
	                 $GLOBALS['LOCATION_DIR']."?id=".$item->LID."\">".$item->LName."</a>"));
	       } 
	      if($item->Description != null) { 
	          array_push($tblarr,array($GLOBALS['S_DESC'],$item->Description));
	      }
	      if(trim($item->CName) != $GLOBALS['S_FORM_CON']) { 
	        array_push($tblarr,array($GLOBALS['S_CONTACT'],"<a href=\"".$GLOBALS['HTTP_DOCUMENT_ROOT'].
	             $GLOBALS['CONTACT_FORM']."?id=".$item->CID."\">".$item->CName."</a>"));
	      } 
	      else {
	         array_push($tblarr,array($GLOBALS['S_CONTACT'],"<a href=\"".$GLOBALS['HTTP_DOCUMENT_ROOT'].$GLOBALS['CALENDAR_PATH'].
	                 $GLOBALS['ITEM_CAL_FILE']."?id=".$item->ID."&amp;form=yes\">".
	                 $GLOBALS['S_CLICK_TO']." ".$GLOBALS['S_FORM_LOC_CONT_INFO']."</a>"));
	      }
	      if($item->ATitle != $GLOBALS['N_AUDIO_NONE']) { 
	          array_push($tblarr,array($GLOBALS['S_AUDIO'],"<a href=\"".$GLOBALS['HTTP_DOCUMENT_ROOT'].
	             $GLOBALS['MESSAGES_DIR'].$GLOBALS['MESSAGES_FILE']."?id=".$item->AID."\">".$item->ATitle."</a>"));
	      }
	      return UtilHtml::createTable($tblarr,$tblheader,$tblclass,"","",$tbltdclass);
	   }
}
?>
