<?php
/**
 * <b>Database Class : Config</b><br />
 * Handles all database-stored configuration data
 * @author Daniel Andrews <daniel_paristemi-com>
 * @copyright Copyright 2004, Kristen O'Brien
 * @license http://opensource.org/licenses/gpl-license.php GNU Public License
 * @link http://www.paristemi.com Paristemi Main Site
 * @package paristemi
 * @subpackage paristemi_database_layer
 * @since Build 0.8
 * @version Build 0.8
 * @filesource
 */

class DB_Config
{
	/**
	* Constructor
	* Loads the variables from the database and globalizes them
	*/
	function DB_Config()
	{
		$this->var_array = array();
		$this->error_msg = '';
		$this->is_loaded = false;
	}
	
	
	/**
	 * readConfig()
	 * Reads all the configuration values from the database and
	 * globalizes the data
	 */
	function readConfig()
	{
		if ($this->is_loaded)
		{
			// prevent the configuration from being loaded twice
			return true;
		}
		
		// Load all the current config values from the database
		$sql = "SELECT config_name, config_value, config_isarray
				FROM paristemi_bt_config;";

		$result = @mysql_query($sql);
		
		if (!$result)
		{
			$this->error_msg = 'DB_Config::readConfig: Configuration data query failed: ('
				. htmlspecialchars(@mysql_errno()) . ') ' . htmlspecialchars(@mysql_error());
			return false;
		}
		
		while ($row = @mysql_fetch_assoc($result))
		{
			// deserialize from a string to an array
			if ($row['config_isarray'])
			{
				$row['config_value'] = unserialize($row['config_value']);
			}
			
			// mark this variable as up-to-date
			$this->var_array[ $row['config_name'] ] = true;
			
			// globalize the variable
			$GLOBALS[ $row['config_name'] ] = $row['config_value'];
		}
		
		// mark that we have loaded the config
		$this->is_loaded = true;
		
		// all done
		return true;
	}
	
	
	/**
	 * setVariable()
	 * Sets the given variable to a new value
	 * 		$var	- the name of the variable
	 * 		$value 	- the new value
	 */
	function setVariable($var, $value)
	{
		$var = trim($var);
		
		// load the configuration if we have not already
		// (not very likely)
		if (!$this->is_loaded)
		{
			$this->readConfig();
		}
		
		// check to verify this variable is in the config table
		if (!isset($this->var_array[ $var ]))
		{
			$this->error_msg = 'DB_Config::setVariable: specified variable is not in the config table';
			return false;
		}
		
		// set this variable as changed
		$this->var_array[ $var ] = false;
		
		// reset the global value of the variable
		$GLOBALS[ $var ] = $value;
		
		return true;
	}
	
	
	/**
	 * writeConfig()
	 * Writes all modified config vars to the database table
	 */
	function writeConfig()
	{
		$temp_error = '';
		
		// check to see if the configuration is loaded
		if (!$this->is_loaded)
		{
			$this->error_msg = 'DB_Config::writeConfig: Configuration table is not loaded.  Call readConfig() first.';
			return false;
		}
		
		// Loop through the var array looking for any changed vars.
		// If a var is changed, update it in the database.
		foreach ($this->var_array as $key => $value)
		{
			if (!$value && isset($GLOBALS[ $key ]))
			{
				// Format the variable if it is an array value
				if (is_array($GLOBALS[ $key ]))
				{
					$save_isarray = 1;
					$save_value = addslashes(serialize($GLOBALS[ $key ]));
				}
				else
				{
					$save_isarray = 0;
					$save_value = addslashes($GLOBALS[ $key ]);
				}
				
				// Value has been changed since this class instantiation
				// so update the database with its new value.
				$sql = "UPDATE paristemi_bt_config
						SET config_value = '${save_value}', config_isarray = ${save_isarray}
						WHERE config_name = '" . addslashes($key) . "' LIMIT 1;";
				
				$result = @mysql_query($sql);
				
				if (!$result)
				{
					// query failed
					$temp_error .= 'DB_Config::writeConfig: Configuration data query failed: ('
						. htmlspecialchars(@mysql_errno()) . ') ' . htmlspecialchars(@mysql_error()) . "\n";
				}
			}
		}
		
		// determine if we encountered any errors during the update
		if ($temp_error == '')
		{
			// all went ok
			return true;
		}
		else
		{
			// errors/problems occured
			$this->error_msg = $temp_error;
			return false;
		}
	}
	
	
	/**
	 * writeConfigFile()
	 * Writes the configuration data to a PHP-includable file
	 * 		$file - The file path to write
	 * NOTE: Uses var_export() which is PHP >= 4.2.0
	 */
	function writeConfigFile($outfile)
	{
		// check to see if the configuration is loaded
		if (!$this->is_loaded)
		{
			$this->error_msg = 'DB_Config::writeConfigFile: Configuration table is not loaded.  Call readConfig() first.';
			return false;
		}
		
		$output_data = "<" . "?php\n\n// Configuration file exported "
			. date('d M Y, H:i', time()) . "\n\n";
		
		// loop through the config variables, adding each to the output
		foreach ($this->var_array as $key => $value)
		{
			// Set a default value in the event of an unset var (not likely)
			if (!isset($GLOBALS[ $key ]))
			{
				$GLOBALS[ $key ] = '';
			}
			
			$output_data .= '$' . $key . ' = ' . var_export($GLOBALS[ $key ], true) . ";\n\n";
		}
		
		$output_data .= '?' . '>';

		// open the output file and save the data
		$file_handle = @fopen($outfile, 'w');

		if (!$file_handle)
		{
			$this->error_msg = 'DB_config::writeConfigFile: Could not open output file stream.';
			return false;
		}

		@fwrite($file_handle, $output_data);
		@fclose($file_handle);
		
		return true;
	}
	
	
	/**
	 * getError()
	 * Returns the most recent error message
	 */
	function getError()
	{
		return $this->error_msg;
	}

	
	/**
	 * Private variables
	 */
	var $is_loaded;
	var $var_array;
	var $error_msg;
}

?>
