<?php
/**
* <b>Site Validation</b><br />
* The class contains a group of data validation functions
* @author Daniel Andrews, Kristen O'Brien
* @copyright Copyright 2005, Kristen O'Brien
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
* @link http://www.paristemi.com Paristemi Main Site
* @package paristemi
* @subpackage paristemi_util
* @since Build 0.8
* @version Build 0.8
* @filesource
*/
/**
* Include the constants file and all of the files in the include list
*/
if(isset($SERVER_DIRECTORY) && file_exists($SERVER_DIRECTORY."constants.php")) { require_once($SERVER_DIRECTORY."constants.php"); } else if(ltrim(dirname($_SERVER['SCRIPT_FILENAME'])) != "" && file_exists($_SERVER['DOCUMENT_ROOT']."/constants.php")) {     require_once($_SERVER['DOCUMENT_ROOT']."/constants.php"); } else if(file_exists("../constants.php")) { require_once("../constants.php"); } else { require_once("constants.php"); }
foreach($INCLUDE_LIST as $includefile) { require_once $includefile; }

class UtilValidation
{
    /**
    * Check form fields for valid entries
    */
    function checkValidators($validators,$formtype="POST")
    {
        $validator_errors = array();
        if($formtype == "POST") {
            foreach($validators as $validator) {
                $is_valid = false;
                switch($validator['check']) {
                    case 'date' : $is_valid = UtilValidation::isDate($_POST[$validator['field']]); break;
                    case 'email' : $is_valid = UtilValidation::isEmail($_POST[$validator['field']]); break;
                    case 'existing' : $is_valid = UtilValidation::isExisting($validator['field'],$formtype); break;
                    case 'notEmpty' : $is_valid = UtilValidation::isNotEmpty($_POST[$validator['field']]); break;
                    case 'number' : $is_valid = UtilValidation::isNumber($_POST[$validator['field']]); break;
                    case 'SQLDate' : $is_valid = UtilValidation::isSQLDate($_POST[$validator['field']]); break;
                    case 'SQLDateTime' : $is_valid = UtilValidation::isSQLDateTime($_POST[$validator['field']]); break;
                    case 'URL' : $is_valid = UtilValidation::isURL($_POST[$validator['field']]); break;
                }
                if(!$is_valid)
                    $validator_errors[] = $validator;
            }
        }
        else if($formtype == "GET") {
            foreach($validators as $validator) {
                $is_valid = false;
                switch($validator['check']) {
                    case 'date' : $is_valid = UtilValidation::isDate($_GET[$validator['field']]); break;
                    case 'email' : $is_valid = UtilValidation::isEmail($_GET[$validator['field']]); break;
                    case 'existing' : $is_valid = UtilValidation::isExisting($validator['field'],$formtype); break;
                    case 'notEmpty' : $is_valid = UtilValidation::isNotEmpty($_GET[$validator['field']]); break;
                    case 'number' : $is_valid = UtilValidation::isNumber($_GET[$validator['field']]); break;
                    case 'SQLDate' : $is_valid = UtilValidation::isSQLDate($_GET[$validator['field']]); break;
                    case 'SQLDateTime' : $is_valid = UtilValidation::isSQLDateTime($_GET[$validator['field']]); break;
                    case 'URL' : $is_valid = UtilValidation::isURL($_GET[$validator['field']]); break;
                }
                if(!$is_valid)
                    $validator_errors[] = $validator;
            }
        }
        return $validator_errors;
    }
    
	/**
	 * E-Mail address validation
	 */
	function isEmail($input)
	{
		return preg_match("#[a-z0-9\-_\.]+@[\w\-]+\.(?:[\w\-\.]+\.)*[\w]+#i", trim($input));
	}
    
    /**
     * URL address validation
     * By hex6ng at yahoo dot com
     * from http://us3.php.net/manual/en/function.preg-match-all.php (user notes)
     */
     function isURL($input)
     {
         return preg_match("|\w{3,10}://[\w\.\-_]+(:\d+)?[^\s\"\'<>\(\)\{\}]*|",trim($input));
     }
    
    /**
    * Check if a string is empty
    */
    function isNotEmpty($input)
    {
        return (trim($input) != '');
    }
    
    /**
    * Check if a string is a number
    */
    function isNumber($input)
    {
        return is_numeric(trim($input));
    }
    
    /**
    * Check if a string can be converted to a date
    */
    function isDate($input)
    {
        // note for compatibility with 5.1 this needs to change to check for false
        return (strtotime(trim($input)) != -1);
    }
    
    /**
    * Check if a string is an SQL Date string
    */
    function isSQLDate($input)
    {
        return preg_match("/\d{4}-\d{2}-\d{2}/", trim($input));
    }
    
    /**
    * Check if a string is an SQL DateTime string
    */
    function isSQLDateTime($input)
    {
        return preg_match("/\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}/", trim($input));
    }
    
    /**
    * Check if a variable has been set
    */
    function isExisting($input_variable,$input_type="POST")
    {
        if($input_type == "POST")
            return isset($_POST[$input_variable]);
        if($input_type == "GET")
            return isset($_GET[$input_variable]);
        return false;
    }
}
?>